@@ -20,31 +20,50 @@ class Content():
 
     def locate(self, term, forward=False, tag=False, plural=False):
         value = ''
+
+        terms = term.split()
+        length = len(terms)
+
         sentences = self.sentences
         for sentence in sentences:
             sentence = Content(sentence)
+            words = sentence.clean_words
+            start = ''
+            end = ''
 
-            if term in sentence.clean_words:
-                index = sentence.clean_words.index(term)
-                if not forward and self.is_proper(index - 1):
+            for number in range(0, len(words) - (length - 1)):
+                if words[number:number + length] == terms:
+                    start = number
+                    end = number + length - 1
+
+            if start != '':
+                print(
+                    self.words[start - 2:start + 1],
+                    self.words[start - 1],
+                    self.is_proper(start - 1)
+                )
+                if not forward and self.is_proper(start - 1):
                     if plural:
-                        value = sentence.read_plural(index - 1, forward=False)
-                    value = sentence.read_element(index - 1, forward=False)
+                        value = sentence.read_plural(start - 1, forward=False)
+                    value = sentence.read_element(start - 1, forward=False)
                 elif(
-                    len(sentence.clean_words) > index + 1 and
-                    sentence.clean_words[index + 1] == 'of' and
+                    len(sentence.clean_words) > end + 1 and
+                    sentence.clean_words[end + 1] == 'of' and
                     not forward
                 ):
                     if plural:
-                        value = sentence.read_plural(index + 2)
-                    value = sentence.read_element(index + 2)
+                        value = sentence.read_plural(end + 2)
+                    value = sentence.read_element(end + 2)
                 else:
                     if plural:
-                        value = sentence.read_plural(index + 1)
-                    value = sentence.read_element(index + 1)
+                        value = sentence.read_plural(end + 1)
+                    value = sentence.read_element(end + 1)
             if tag:
                 if value:
-                    value = value + ' ' + term.capitalize()
+                    if length > 1:
+                        value = value + ' ' + term
+                    else:
+                        value = value + ' ' + term.capitalize()
         return value
 
     def is_proper(self, index):
@@ -58,11 +77,17 @@ class Content():
         terms = []
         while True:
             if len(self.words) > index >= 0:
+                term = self.words[index]
+                if (not terms) and term.lower() == 'the':
+                    return term
                 if self.is_proper(index):
-                    term = self.words[index]
+                    stop = False
                     if term[-1] == ',':
                         term = term[:-1]
+                        stop = True
                     terms.append(term)
+                    if stop:
+                        break
                 else:
                     break
             else:
